@@ -13,11 +13,11 @@ Class::Debug - Add Runtime Debugging to a Class
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 SYNOPSIS
 
@@ -167,10 +167,14 @@ sub setup
 
 	# Load the default logger, which may have been defined in the config file or passed in
 	if(my $logger = $params->{'logger'}) {
-		if((ref($logger) eq 'HASH') && $logger->{'syslog'}) {
-			$params->{'logger'} = Log::Abstraction->new({ carp_on_warn => 1, syslog => $logger->{'syslog'}, %{$logger} });
+		if(ref($logger) eq 'HASH') {
+			if($logger->{'syslog'}) {
+				$params->{'logger'} = Log::Abstraction->new({ carp_on_warn => 1, syslog => $logger->{'syslog'}, %{$logger} });
+			} else {
+				$params->{'logger'} = Log::Abstraction->new({ carp_on_warn => 1, %{$logger} });
+			}
 		} else {
-			$params->{'logger'} = Log::Abstraction->new({ carp_on_warn => 1, %{$logger} });
+			$params->{'logger'} = Log::Abstraction->new({ carp_on_warn => 1, logger => $logger });
 		}
 	} else {
 		$params->{'logger'} = Log::Abstraction->new(carp_on_warn => 1);
